Add

Trait Add 

1.0.0 (const: unstable) · Source
pub trait Add<Rhs = Self> {
    type Output;

    // Required method
    fn add(self, rhs: Rhs) -> Self::Output;
}
The addition operator +.

Note that Rhs is Self by default, but this is not mandatory. For example, std::time::SystemTime implements Add<Duration>, which permits operations of the form SystemTime = SystemTime + Duration.

Examples

Addable points

use std::ops::Add;

#[derive(Debug, Copy, Clone, PartialEq)]
struct Point {
    x: i32,
    y: i32,
}

impl Add for Point {
    type Output = Self;

    fn add(self, other: Self) -> Self {
        Self {
            x: self.x + other.x,
            y: self.y + other.y,
        }
    }
}

assert_eq!(Point { x: 1, y: 0 } + Point { x: 2, y: 3 },
           Point { x: 3, y: 3 });

Implementing Add with generics

Here is an example of the same Point struct implementing the Add trait using generics.

use std::ops::Add;

#[derive(Debug, Copy, Clone, PartialEq)]
struct Point<T> {
    x: T,
    y: T,
}

// Notice that the implementation uses the associated type `Output`.
impl<T: Add<Output = T>> Add for Point<T> {
    type Output = Self;

    fn add(self, other: Self) -> Self::Output {
        Self {
            x: self.x + other.x,
            y: self.y + other.y,
        }
    }
}

assert_eq!(Point { x: 1, y: 0 } + Point { x: 2, y: 3 },
           Point { x: 3, y: 3 });

Required Associated Types

1.0.0 (const: unstable) · Source

type Output

The resulting type after applying the + operator.

Required Methods

1.0.0 (const: unstable) · Source

fn add(self, rhs: Rhs) -> Self::Output

Performs the + operation.

Example
assert_eq!(12 + 1, 13);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Add for Assume

Source

impl Add for BigInt

Source

impl Add for BigUint

1.3.0 (const: unstable) · Source

impl Add for Duration

Source

impl Add for Fe32

1.74.0 (const: unstable) · Source

impl Add for Saturating<i8>

1.74.0 (const: unstable) · Source

impl Add for Saturating<i16>

1.74.0 (const: unstable) · Source

impl Add for Saturating<i32>

1.74.0 (const: unstable) · Source

impl Add for Saturating<i64>

1.74.0 (const: unstable) · Source

impl Add for Saturating<i128>

1.74.0 (const: unstable) · Source

impl Add for Saturating<isize>

1.74.0 (const: unstable) · Source

impl Add for Saturating<u8>

1.74.0 (const: unstable) · Source

impl Add for Saturating<u16>

1.74.0 (const: unstable) · Source

impl Add for Saturating<u32>

1.74.0 (const: unstable) · Source

impl Add for Saturating<u64>

1.74.0 (const: unstable) · Source

impl Add for Saturating<u128>

1.74.0 (const: unstable) · Source

impl Add for Saturating<usize>

1.0.0 (const: unstable) · Source

impl Add for Wrapping<i8>

1.0.0 (const: unstable) · Source

impl Add for Wrapping<i16>

1.0.0 (const: unstable) · Source

impl Add for Wrapping<i32>

1.0.0 (const: unstable) · Source

impl Add for Wrapping<i64>

1.0.0 (const: unstable) · Source

impl Add for Wrapping<i128>

1.0.0 (const: unstable) · Source

impl Add for Wrapping<isize>

1.0.0 (const: unstable) · Source

impl Add for Wrapping<u8>

1.0.0 (const: unstable) · Source

impl Add for Wrapping<u16>

1.0.0 (const: unstable) · Source

impl Add for Wrapping<u32>

1.0.0 (const: unstable) · Source

impl Add for Wrapping<u64>

1.0.0 (const: unstable) · Source

impl Add for Wrapping<u128>

1.0.0 (const: unstable) · Source

impl Add for Wrapping<usize>

1.0.0 (const: unstable) · Source

impl Add for f16

1.0.0 (const: unstable) · Source

impl Add for f32

1.0.0 (const: unstable) · Source

impl Add for f64

1.0.0 (const: unstable) · Source

impl Add for f128

1.0.0 (const: unstable) · Source

impl Add for i8

1.0.0 (const: unstable) · Source

impl Add for i16

1.0.0 (const: unstable) · Source

impl Add for i32

1.0.0 (const: unstable) · Source

impl Add for i64

1.0.0 (const: unstable) · Source

impl Add for i128

1.0.0 (const: unstable) · Source

impl Add for isize

1.0.0 (const: unstable) · Source

impl Add for u8

1.0.0 (const: unstable) · Source

impl Add for u16

1.0.0 (const: unstable) · Source

impl Add for u32

1.0.0 (const: unstable) · Source

impl Add for u64

1.0.0 (const: unstable) · Source

impl Add for u128

1.0.0 (const: unstable) · Source

impl Add for usize

Source

impl Add<&BigInt> for &BigInt

Source

impl Add<&BigInt> for &i8

Source

impl Add<&BigInt> for &i16

Source

impl Add<&BigInt> for &i32

Source

impl Add<&BigInt> for &i64

Source

impl Add<&BigInt> for &i128

Source

impl Add<&BigInt> for &isize

Source

impl Add<&BigInt> for &u8

Source

impl Add<&BigInt> for &u16

Source

impl Add<&BigInt> for &u32

Source

impl Add<&BigInt> for &u64

Source

impl Add<&BigInt> for &u128

Source

impl Add<&BigInt> for &usize

Source

impl Add<&BigInt> for BigInt

Source

impl Add<&BigInt> for i8

Source

impl Add<&BigInt> for i16

Source

impl Add<&BigInt> for i32

Source

impl Add<&BigInt> for i64

Source

impl Add<&BigInt> for i128

Source

impl Add<&BigInt> for isize

Source

impl Add<&BigInt> for u8

Source

impl Add<&BigInt> for u16

Source

impl Add<&BigInt> for u32

Source

impl Add<&BigInt> for u64

Source

impl Add<&BigInt> for u128

Source

impl Add<&BigInt> for usize

Source

impl Add<&BigUint> for &BigUint

Source

impl Add<&BigUint> for &u8

Source

impl Add<&BigUint> for &u16

Source

impl Add<&BigUint> for &u32

Source

impl Add<&BigUint> for &u64

Source

impl Add<&BigUint> for &u128

Source

impl Add<&BigUint> for &usize

Source

impl Add<&BigUint> for BigUint

Source

impl Add<&BigUint> for u8

Source

impl Add<&BigUint> for u16

Source

impl Add<&BigUint> for u32

Source

impl Add<&BigUint> for u64

Source

impl Add<&BigUint> for u128

Source

impl Add<&BigUint> for usize

Source

impl Add<&Fe32> for &Fe32

Source

impl Add<&Fe32> for Fe32

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i8>> for &Saturating<i8>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i8>> for Saturating<i8>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i16>> for &Saturating<i16>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i16>> for Saturating<i16>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i32>> for &Saturating<i32>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i32>> for Saturating<i32>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i64>> for &Saturating<i64>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i64>> for Saturating<i64>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i128>> for &Saturating<i128>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<i128>> for Saturating<i128>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<isize>> for &Saturating<isize>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<isize>> for Saturating<isize>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u8>> for &Saturating<u8>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u8>> for Saturating<u8>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u16>> for &Saturating<u16>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u16>> for Saturating<u16>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u32>> for &Saturating<u32>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u32>> for Saturating<u32>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u64>> for &Saturating<u64>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u64>> for Saturating<u64>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u128>> for &Saturating<u128>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<u128>> for Saturating<u128>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<usize>> for &Saturating<usize>

1.74.0 (const: unstable) · Source

impl Add<&Saturating<usize>> for Saturating<usize>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i8>> for &Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i8>> for Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i16>> for &Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i16>> for Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i32>> for &Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i32>> for Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i64>> for &Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i64>> for Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i128>> for &Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<i128>> for Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<isize>> for &Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<isize>> for Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u8>> for &Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u8>> for Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u16>> for &Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u16>> for Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u32>> for &Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u32>> for Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u64>> for &Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u64>> for Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u128>> for &Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<u128>> for Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<usize>> for &Wrapping<usize>

1.14.0 (const: unstable) · Source

impl Add<&Wrapping<usize>> for Wrapping<usize>

1.0.0 (const: unstable) · Source

impl Add<&f16> for &f16

1.0.0 (const: unstable) · Source

impl Add<&f16> for f16

1.0.0 (const: unstable) · Source

impl Add<&f32> for &f32

1.0.0 (const: unstable) · Source

impl Add<&f32> for f32

1.0.0 (const: unstable) · Source

impl Add<&f64> for &f64

1.0.0 (const: unstable) · Source

impl Add<&f64> for f64

1.0.0 (const: unstable) · Source

impl Add<&f128> for &f128

1.0.0 (const: unstable) · Source

impl Add<&f128> for f128

Source

impl Add<&i8> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<&i8> for &i8

Source

impl Add<&i8> for BigInt

1.0.0 (const: unstable) · Source

impl Add<&i8> for i8

Source

impl Add<&i16> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<&i16> for &i16

Source

impl Add<&i16> for BigInt

1.0.0 (const: unstable) · Source

impl Add<&i16> for i16

Source

impl Add<&i32> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<&i32> for &i32

Source

impl Add<&i32> for BigInt

1.0.0 (const: unstable) · Source

impl Add<&i32> for i32

Source

impl Add<&i64> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<&i64> for &i64

Source

impl Add<&i64> for BigInt

1.0.0 (const: unstable) · Source

impl Add<&i64> for i64

Source

impl Add<&i128> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<&i128> for &i128

Source

impl Add<&i128> for BigInt

1.0.0 (const: unstable) · Source

impl Add<&i128> for i128

Source

impl Add<&isize> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<&isize> for &isize

Source

impl Add<&isize> for BigInt

1.0.0 (const: unstable) · Source

impl Add<&isize> for isize

1.0.0 · Source

impl Add<&str> for String

Available on non-no_global_oom_handling only.

Implements the + operator for concatenating two strings.

This consumes the String on the left-hand side and re-uses its buffer (growing it if necessary). This is done to avoid allocating a new String and copying the entire contents on every operation, which would lead to O(n^2) running time when building an n-byte string by repeated concatenation.

The string on the right-hand side is only borrowed; its contents are copied into the returned String.

Examples

Concatenating two Strings takes the first by value and borrows the second:

let a = String::from("hello");
let b = String::from(" world");
let c = a + &b;
// `a` is moved and can no longer be used here.

If you want to keep using the first String, you can clone it and append to the clone instead:

let a = String::from("hello");
let b = String::from(" world");
let c = a.clone() + &b;
// `a` is still valid here.

Concatenating &str slices can be done by converting the first to a String:

let a = "hello";
let b = " world";
let c = a.to_string() + b;
Source

impl Add<&u8> for &BigInt

Source

impl Add<&u8> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<&u8> for &u8

Source

impl Add<&u8> for BigInt

Source

impl Add<&u8> for BigUint

1.0.0 (const: unstable) · Source

impl Add<&u8> for u8

Source

impl Add<&u16> for &BigInt

Source

impl Add<&u16> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<&u16> for &u16

Source

impl Add<&u16> for BigInt

Source

impl Add<&u16> for BigUint

1.0.0 (const: unstable) · Source

impl Add<&u16> for u16

Source

impl Add<&u32> for &BigInt

Source

impl Add<&u32> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<&u32> for &u32

Source

impl Add<&u32> for BigInt

Source

impl Add<&u32> for BigUint

1.0.0 (const: unstable) · Source

impl Add<&u32> for u32

Source

impl Add<&u64> for &BigInt

Source

impl Add<&u64> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<&u64> for &u64

Source

impl Add<&u64> for BigInt

Source

impl Add<&u64> for BigUint

1.0.0 (const: unstable) · Source

impl Add<&u64> for u64

Source

impl Add<&u128> for &BigInt

Source

impl Add<&u128> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<&u128> for &u128

Source

impl Add<&u128> for BigInt

Source

impl Add<&u128> for BigUint

1.0.0 (const: unstable) · Source

impl Add<&u128> for u128

Source

impl Add<&usize> for &BigInt

Source

impl Add<&usize> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<&usize> for &usize

Source

impl Add<&usize> for BigInt

Source

impl Add<&usize> for BigUint

1.0.0 (const: unstable) · Source

impl Add<&usize> for usize

Source

impl Add<BigInt> for &BigInt

Source

impl Add<BigInt> for &i8

Source

impl Add<BigInt> for &i16

Source

impl Add<BigInt> for &i32

Source

impl Add<BigInt> for &i64

Source

impl Add<BigInt> for &i128

Source

impl Add<BigInt> for &isize

Source

impl Add<BigInt> for &u8

Source

impl Add<BigInt> for &u16

Source

impl Add<BigInt> for &u32

Source

impl Add<BigInt> for &u64

Source

impl Add<BigInt> for &u128

Source

impl Add<BigInt> for &usize

Source

impl Add<BigInt> for i8

Source

impl Add<BigInt> for i16

Source

impl Add<BigInt> for i32

Source

impl Add<BigInt> for i64

Source

impl Add<BigInt> for i128

Source

impl Add<BigInt> for isize

Source

impl Add<BigInt> for u8

Source

impl Add<BigInt> for u16

Source

impl Add<BigInt> for u32

Source

impl Add<BigInt> for u64

Source

impl Add<BigInt> for u128

Source

impl Add<BigInt> for usize

Source

impl Add<BigUint> for &BigUint

Source

impl Add<BigUint> for &u8

Source

impl Add<BigUint> for &u16

Source

impl Add<BigUint> for &u32

Source

impl Add<BigUint> for &u64

Source

impl Add<BigUint> for &u128

Source

impl Add<BigUint> for &usize

Source

impl Add<BigUint> for u8

Source

impl Add<BigUint> for u16

Source

impl Add<BigUint> for u32

Source

impl Add<BigUint> for u64

Source

impl Add<BigUint> for u128

Source

impl Add<BigUint> for usize

1.8.0 · Source

impl Add<Duration> for Instant

1.8.0 · Source

impl Add<Duration> for SystemTime

Source

impl Add<Fe32> for &Fe32

1.74.0 (const: unstable) · Source

impl Add<Saturating<i8>> for &Saturating<i8>

1.74.0 (const: unstable) · Source

impl Add<Saturating<i16>> for &Saturating<i16>

1.74.0 (const: unstable) · Source

impl Add<Saturating<i32>> for &Saturating<i32>

1.74.0 (const: unstable) · Source

impl Add<Saturating<i64>> for &Saturating<i64>

1.74.0 (const: unstable) · Source

impl Add<Saturating<i128>> for &Saturating<i128>

1.74.0 (const: unstable) · Source

impl Add<Saturating<isize>> for &Saturating<isize>

1.74.0 (const: unstable) · Source

impl Add<Saturating<u8>> for &Saturating<u8>

1.74.0 (const: unstable) · Source

impl Add<Saturating<u16>> for &Saturating<u16>

1.74.0 (const: unstable) · Source

impl Add<Saturating<u32>> for &Saturating<u32>

1.74.0 (const: unstable) · Source

impl Add<Saturating<u64>> for &Saturating<u64>

1.74.0 (const: unstable) · Source

impl Add<Saturating<u128>> for &Saturating<u128>

1.74.0 (const: unstable) · Source

impl Add<Saturating<usize>> for &Saturating<usize>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<i8>> for &Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<i16>> for &Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<i32>> for &Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<i64>> for &Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<i128>> for &Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<isize>> for &Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<u8>> for &Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<u16>> for &Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<u32>> for &Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<u64>> for &Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<u128>> for &Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Add<Wrapping<usize>> for &Wrapping<usize>

1.0.0 (const: unstable) · Source

impl Add<f16> for &f16

1.0.0 (const: unstable) · Source

impl Add<f32> for &f32

1.0.0 (const: unstable) · Source

impl Add<f64> for &f64

1.0.0 (const: unstable) · Source

impl Add<f128> for &f128

Source

impl Add<i8> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<i8> for &i8

Source

impl Add<i8> for BigInt

Source

impl Add<i16> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<i16> for &i16

Source

impl Add<i16> for BigInt

Source

impl Add<i32> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<i32> for &i32

Source

impl Add<i32> for BigInt

Source

impl Add<i64> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<i64> for &i64

Source

impl Add<i64> for BigInt

Source

impl Add<i128> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<i128> for &i128

Source

impl Add<i128> for BigInt

Source

impl Add<isize> for &BigInt

1.0.0 (const: unstable) · Source

impl Add<isize> for &isize

Source

impl Add<isize> for BigInt

Source

impl Add<u8> for &BigInt

Source

impl Add<u8> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<u8> for &u8

Source

impl Add<u8> for BigInt

Source

impl Add<u8> for BigUint

Source

impl Add<u16> for &BigInt

Source

impl Add<u16> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<u16> for &u16

Source

impl Add<u16> for BigInt

Source

impl Add<u16> for BigUint

Source

impl Add<u32> for &BigInt

Source

impl Add<u32> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<u32> for &u32

Source

impl Add<u32> for BigInt

Source

impl Add<u32> for BigUint

Source

impl Add<u64> for &BigInt

Source

impl Add<u64> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<u64> for &u64

Source

impl Add<u64> for BigInt

Source

impl Add<u64> for BigUint

Source

impl Add<u128> for &BigInt

Source

impl Add<u128> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<u128> for &u128

Source

impl Add<u128> for BigInt

Source

impl Add<u128> for BigUint

Source

impl Add<usize> for &BigInt

Source

impl Add<usize> for &BigUint

1.0.0 (const: unstable) · Source

impl Add<usize> for &usize

Source

impl Add<usize> for BigInt

Source

impl Add<usize> for BigUint

Source

impl<'a, P> Add<&'a Projective<P>> for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>

Source

impl<'a, P> Add<&'a Projective<P>> for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>

Source

impl<'a, P> Add<&'a mut Fp2<P>> for Fp2<P>
where P: Fp2Parameters,

Source

impl<'a, P> Add<&'a mut Fp6<P>> for Fp6<P>
where P: Fp6Parameters,

Source

impl<'a, P> Add<&'a mut Fp12<P>> for Fp12<P>
where P: Fp12Parameters,

Source

impl<'a, P> Add<&'a mut Fp256<P>> for Fp256<P>
where P: Fp256Parameters,

Source

impl<'a, P> Add<&'a mut Fp384<P>> for Fp384<P>
where P: Fp384Parameters,

Source

impl<'a, P> Add<&'a mut Projective<P>> for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>

Source

impl<'a, P> Add<&'a mut Projective<P>> for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>

1.14.0 · Source

impl<'a> Add for Cow<'a, str>

Available on non-no_global_oom_handling only.
Source

type Output = Cow<'a, str>

1.14.0 · Source

impl<'a> Add<&'a str> for Cow<'a, str>

Available on non-no_global_oom_handling only.
Source

type Output = Cow<'a, str>

Source

impl<'lhs, 'rhs, T, const N: usize> Add<&'rhs Simd<T, N>> for &'lhs Simd<T, N>
where T: SimdElement, Simd<T, N>: Add<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<P> Add for Fp2<P>
where P: Fp2Parameters,

Source

impl<P> Add for Fp6<P>
where P: Fp6Parameters,

Source

impl<P> Add for Fp12<P>
where P: Fp12Parameters,

Source

impl<P> Add for Fp256<P>
where P: Fp256Parameters,

Source

impl<P> Add for Fp384<P>
where P: Fp384Parameters,

Source

impl<P> Add for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>

Source

impl<P> Add for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>

Source

impl<P> Add<&&Fp2<P>> for Fp2<P>
where P: Fp2Parameters,

Source

impl<P> Add<&&Fp6<P>> for Fp6<P>
where P: Fp6Parameters,

Source

impl<P> Add<&&Fp12<P>> for Fp12<P>
where P: Fp12Parameters,

Source

impl<P> Add<&&Fp256<P>> for Fp256<P>
where P: Fp256Parameters,

Source

impl<P> Add<&&Fp384<P>> for Fp384<P>
where P: Fp384Parameters,

Source

impl<P> Add<&&Projective<P>> for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>

Source

impl<P> Add<&&Projective<P>> for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>

Source

impl<P> Add<&Fp2<P>> for Fp2<P>
where P: Fp2Parameters,

Source

impl<P> Add<&Fp6<P>> for Fp6<P>
where P: Fp6Parameters,

Source

impl<P> Add<&Fp12<P>> for Fp12<P>
where P: Fp12Parameters,

Source

impl<P> Add<&Fp256<P>> for Fp256<P>
where P: Fp256Parameters,

Source

impl<P> Add<&Fp384<P>> for Fp384<P>
where P: Fp384Parameters,

Source

impl<T, const N: usize> Add<&Simd<T, N>> for Simd<T, N>
where T: SimdElement, Simd<T, N>: Add<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<T, const N: usize> Add<Simd<T, N>> for &Simd<T, N>
where T: SimdElement, Simd<T, N>: Add<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<const N: usize> Add for Simd<f16, N>

Source

impl<const N: usize> Add for Simd<f32, N>

Source

impl<const N: usize> Add for Simd<f64, N>

Source

impl<const N: usize> Add for Simd<i8, N>
where i8: SimdElement,

Source

impl<const N: usize> Add for Simd<i16, N>

Source

impl<const N: usize> Add for Simd<i32, N>

Source

impl<const N: usize> Add for Simd<i64, N>

Source

impl<const N: usize> Add for Simd<isize, N>

Source

impl<const N: usize> Add for Simd<u8, N>
where u8: SimdElement,

Source

impl<const N: usize> Add for Simd<u16, N>

Source

impl<const N: usize> Add for Simd<u32, N>

Source

impl<const N: usize> Add for Simd<u64, N>

Source

impl<const N: usize> Add for Simd<usize, N>